CreateKeyOptions

Struct CreateKeyOptions 

pub struct CreateKeyOptions { /* private fields */ }
Key options that are part of the Create output

Implementations

Source

impl CreateKeyOptions

pub fn allow_user_keys(&self) -> &bool

If set to true, then it is allowed to supply own key values in the _key attribute of a document. If set to false, then the key generator will solely be responsible for generating keys and supplying own key values in the _key attribute of documents is considered an error.

pub fn last_value(&self) -> &usize

The last key value used

pub fn kind(&self) -> &String

Specifies the type of the key generator. The currently available generators are traditional, autoincrement, uuid and padded.

The traditional key generator generates numerical keys in ascending order. The autoincrement key generator generates numerical keys in ascending order, the initial offset and the spacing can be configured (note: autoincrement is currently only supported for non-sharded collections). The padded key generator generates keys of a fixed length (16 bytes) in ascending lexicographical sort order. This is ideal for usage with the RocksDB engine, which will slightly benefit keys that are inserted in lexicographically ascending order. The key generator can be used in a single-server or cluster. The uuid key generator generates universally unique 128 bit keys, which are stored in hexadecimal human-readable format. This key generator can be used in a single-server or cluster to generate “seemingly random” keys. The keys produced by this key generator are not lexicographically sorted.