pub struct CreateVertexConfigBuilder<T> { /* private fields */ }Expand description
Builder for Config.
Implementations
Sourceimpl<T: Clone> ConfigBuilder<T>
impl<T: Clone> ConfigBuilder<T>
Sourcepub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The name of the graph to add the vertex to
Sourcepub fn collection<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn collection<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The name of the collection to add the vertex to
Sourcepub fn wait_for_sync(&mut self, value: bool) -> &mut Self
pub fn wait_for_sync(&mut self, value: bool) -> &mut Self
Wait until the graph has been synced to disk
Sourcepub fn return_new(&mut self, value: bool) -> &mut Self
pub fn return_new(&mut self, value: bool) -> &mut Self
Return the new vertex in the response