pub struct EdgeDefinitionBuilder { /* private fields */ }Expand description
Builder for EdgeDefinition.
Implementations
Sourceimpl EdgeDefinitionBuilder
impl EdgeDefinitionBuilder
Sourcepub fn collection<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn collection<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Name of the edge collection, where the edge are stored in.
Sourcepub fn to<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
pub fn to<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
List of vertex collection names.
Edges in collection can only be inserted if their _to is in
any of the collections here.
Sourcepub fn from(&mut self, value: Vec<String>) -> &mut Self
pub fn from(&mut self, value: Vec<String>) -> &mut Self
List of vertex collection names.
Edges in collection can only be inserted if their _to is in
any of the collections here.
Sourcepub fn build(&self) -> Result<EdgeDefinition, EdgeDefinitionBuilderError>
pub fn build(&self) -> Result<EdgeDefinition, EdgeDefinitionBuilderError>